/// <reference types="node" />
import { OAuth } from 'oauth';
import { IHttpClient } from './BaseAPIClient';
import * as fs from 'fs';
import * as http from 'http';
import { AttachmentsResponse } from '../AccountingAPI-responses';
export interface RequestToken {
    oauth_token: string;
    oauth_token_secret: string;
}
export interface AccessToken extends RequestToken {
    oauth_session_handle?: string;
    oauth_expires_at?: Date;
}
/** @private */
export interface OAuth1Configuration {
    consumerKey: string;
    consumerSecret: string;
    tenantType: string;
    apiBaseUrl: string;
    apiBasePath: string;
    oauthRequestTokenPath: string;
    oauthAccessTokenPath: string;
    signatureMethod: string;
    accept: string;
    userAgent: string;
    callbackUrl: string;
}
/** @private */
export interface IOAuth1Client {
    agent?: http.Agent;
    getRequestToken(): Promise<RequestToken>;
    buildAuthoriseUrl(requestToken: RequestToken): string;
    swapRequestTokenforAccessToken(requestToken: RequestToken, oauth_verifier: string): Promise<AccessToken>;
    refreshAccessToken(): Promise<AccessToken>;
}
/** @private */
export interface IOAuth1HttpClient extends IHttpClient, IOAuth1Client {
}
/** @private */
export declare class OAuth1HttpClient implements IOAuth1HttpClient {
    private config;
    private oAuthLibFactory;
    private _state;
    private oauthLib;
    agent: http.Agent;
    private _defaultHeaders;
    private resetToDefaultHeaders();
    constructor(config: OAuth1Configuration, authState?: AccessToken, oAuthLibFactory?: (config: OAuth1Configuration) => typeof OAuth);
    getRequestToken: () => Promise<RequestToken>;
    buildAuthoriseUrl: (requestToken: RequestToken) => string;
    swapRequestTokenforAccessToken: (requestToken: RequestToken, oauth_verifier: string) => Promise<AccessToken>;
    refreshAccessToken: () => Promise<AccessToken>;
    writeUTF8ResponseToStream: (endpoint: string, mimeType: string, writeStream: fs.WriteStream) => Promise<void>;
    writeBinaryResponseToStream: (endpoint: string, mimeType: string, writeStream: fs.WriteStream) => Promise<void>;
    private _OURperformSecureRequest;
    readStreamToRequest: (endpoint: string, mimeType: string, size: number, readStream: fs.ReadStream) => Promise<AttachmentsResponse>;
    get: <T>(endpoint: string, customHeaders?: {
        [key: string]: string;
    }) => Promise<T>;
    put: <T>(endpoint: string, body: object, customHeaders?: {
        [key: string]: string;
    }) => Promise<T>;
    post: <T>(endpoint: string, body: object, customHeaders?: {
        [key: string]: string;
    }) => Promise<T>;
    delete: <T>(endpoint: string, customHeaders?: {
        [key: string]: string;
    }) => Promise<T>;
    private setState(newState);
    private assertAccessTokenIsSet();
    private _createHttpClientWithProxySupport(port, hostname, method, path, headers, sslEnabled?);
}
