"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var utils_1 = require("../utils");
var privateKey_helpers_1 = require("./helpers/privateKey-helpers");
describe('getStringFromFile()', function () {
    it('returns string from file', function () {
        var result = utils_1.getStringFromFile(privateKey_helpers_1.validTestCertPath());
        expect(result).toContain('-----BEGIN RSA PRIVATE KEY-----');
        expect(result).toContain('-----END RSA PRIVATE KEY-----');
        expect(result).toContain('VrppKCesvPJmo/4y77Dsxt5ukPEAO3nWrwJAWTzBH0ZeYlGxe8KpTEKW6ZifQb1P');
    });
    it('throws when key not there', function () {
        expect.assertions(2);
        try {
            utils_1.getStringFromFile('./something/test-privatekey.pem');
        }
        catch (error) {
            expect(error.message).toContain('ENOENT: no such file or directory, open');
            expect(error.message).toContain('test-privatekey.pem');
        }
    });
});
describe('generateQueryString()', function () {
    it("empty object becomes ''", function () {
        expect(utils_1.generateQueryString({})).toEqual('');
    });
    it("undefined becomes ''", function () {
        expect(utils_1.generateQueryString(undefined)).toEqual('');
    });
    it("null becomes ''", function () {
        expect(utils_1.generateQueryString(null)).toEqual('');
    });
    it('handles single param', function () {
        expect(utils_1.generateQueryString({ where: 'Type=="ACCREC"' })).toEqual('?where=Type%3D%3D%22ACCREC%22');
    });
    it('omits param whose value is undefined', function () {
        expect(utils_1.generateQueryString({ abc: undefined })).toEqual('');
    });
    it('omits param whose value is undefined, but keeps other params', function () {
        expect(utils_1.generateQueryString({ page: 5, abc: undefined })).toEqual('?page=5');
    });
    it('handles multiple params', function () {
        expect(utils_1.generateQueryString({ page: 5, where: 'Type=="ACCREC"' })).toEqual('?page=5&where=Type%3D%3D%22ACCREC%22');
    });
    it('maintains declaration order for multiple params', function () {
        expect(utils_1.generateQueryString({ where: 'Type=="ACCREC"', page: 5 })).toEqual('?where=Type%3D%3D%22ACCREC%22&page=5');
    });
    describe('addSummarizeErrorsParam', function () {
        it('adds to {}', function () {
            expect(utils_1.generateQueryString({}, true)).toEqual('?summarizeErrors=false');
        });
        it('adds to null', function () {
            expect(utils_1.generateQueryString(null, true)).toEqual('?summarizeErrors=false');
        });
        it('adds to undefined', function () {
            expect(utils_1.generateQueryString(undefined, true)).toEqual('?summarizeErrors=false');
        });
        it('adds to existing params', function () {
            expect(utils_1.generateQueryString({ a: 5 }, true)).toEqual('?a=5&summarizeErrors=false');
        });
        it('preserves value if specified', function () {
            expect(utils_1.generateQueryString({ summarizeErrors: true }, true)).toEqual('?summarizeErrors=true');
        });
        it('preserves order if specified with other params', function () {
            expect(utils_1.generateQueryString({ d: 12, summarizeErrors: true, a: 5 }, true)).toEqual('?d=12&summarizeErrors=true&a=5');
        });
    });
});
